skrt v1.0.0.0
=============

containers
----------
Specialized containers as alternatives to Python's built-in types and to those
defined in the collections standard module.

* **defaultnamedtuple**  factory function for namedtuples with default arguments

utils
-----
Utility functions for manipulating containers.
Thanks `Jack Fischer
<https://www.github.com/jackfischer/>`_, for the idea for ``rmap``.

* **subdict**  extract a subset of a dictionary
* **match**    compare multiple objects based on a list of shared attributes
* **rmap**     recursively map a function onto items of nested containers
